@@ -1,6 +1,6 @@
 use std::cmp::{max, min};
 
-use floem::reactive::{RwSignal, Scope};
+use floem::reactive::{RwSignal, Scope, SignalGet, SignalUpdate, SignalWith};
 use lapce_core::{
     selection::{SelRegion, Selection},
     word::WordCursor,
