@@ -15,7 +15,10 @@ use crossbeam_channel::{Receiver, Sender, TryRecvError};
 use floem::{
     ext_event::{create_ext_action, create_signal_from_channel},
     keyboard::Modifiers,
-    reactive::{use_context, ReadSignal, RwSignal, Scope},
+    reactive::{
+        use_context, ReadSignal, RwSignal, Scope, SignalGet, SignalUpdate,
+        SignalWith,
+    },
 };
 use itertools::Itertools;
 use lapce_core::{
@@ -25,7 +28,7 @@ use lapce_core::{
 };
 use lapce_rpc::proxy::ProxyResponse;
 use lapce_xi_rope::Rope;
-use lsp_types::DocumentSymbolResponse;
+use lsp_types::{DocumentSymbol, DocumentSymbolResponse};
 use nucleo::Utf32Str;
 use strum::{EnumMessage, IntoEnumIterator};
 use tracing::error;
@@ -646,42 +649,7 @@ impl PaletteData {
         let set_items = self.items.write_only();
         let send = create_ext_action(self.common.scope, move |result| {
             if let Ok(ProxyResponse::GetDocumentSymbols { resp }) = result {
-                let items: im::Vector<PaletteItem> = match resp {
-                    DocumentSymbolResponse::Flat(symbols) => symbols
-                        .iter()
-                        .map(|s| {
-                            let mut filter_text = s.name.clone();
-                            if let Some(container_name) = s.container_name.as_ref() {
-                                filter_text += container_name;
-                            }
-                            PaletteItem {
-                                content: PaletteItemContent::DocumentSymbol {
-                                    kind: s.kind,
-                                    name: s.name.clone(),
-                                    range: s.location.range,
-                                    container_name: s.container_name.clone(),
-                                },
-                                filter_text,
-                                score: 0,
-                                indices: Vec::new(),
-                            }
-                        })
-                        .collect(),
-                    DocumentSymbolResponse::Nested(symbols) => symbols
-                        .iter()
-                        .map(|s| PaletteItem {
-                            content: PaletteItemContent::DocumentSymbol {
-                                kind: s.kind,
-                                name: s.name.clone(),
-                                range: s.range,
-                                container_name: None,
-                            },
-                            filter_text: s.name.clone(),
-                            score: 0,
-                            indices: Vec::new(),
-                        })
-                        .collect(),
-                };
+                let items = Self::format_document_symbol_resp(resp);
                 set_items.set(items);
             } else {
                 set_items.update(|items| items.clear());
@@ -693,6 +661,64 @@ impl PaletteData {
         });
     }
 
+    fn format_document_symbol_resp(
+        resp: DocumentSymbolResponse,
+    ) -> im::Vector<PaletteItem> {
+        match resp {
+            DocumentSymbolResponse::Flat(symbols) => symbols
+                .iter()
+                .map(|s| {
+                    let mut filter_text = s.name.clone();
+                    if let Some(container_name) = s.container_name.as_ref() {
+                        filter_text += container_name;
+                    }
+                    PaletteItem {
+                        content: PaletteItemContent::DocumentSymbol {
+                            kind: s.kind,
+                            name: s.name.replace('\n', "↵"),
+                            range: s.location.range,
+                            container_name: s.container_name.clone(),
+                        },
+                        filter_text,
+                        score: 0,
+                        indices: Vec::new(),
+                    }
+                })
+                .collect(),
+            DocumentSymbolResponse::Nested(symbols) => {
+                let mut items = im::Vector::new();
+                for s in symbols {
+                    Self::format_document_symbol(&mut items, None, s)
+                }
+                items
+            }
+        }
+    }
+
+    fn format_document_symbol(
+        items: &mut im::Vector<PaletteItem>,
+        parent: Option<String>,
+        s: DocumentSymbol,
+    ) {
+        items.push_back(PaletteItem {
+            content: PaletteItemContent::DocumentSymbol {
+                kind: s.kind,
+                name: s.name.replace('\n', "↵"),
+                range: s.range,
+                container_name: parent,
+            },
+            filter_text: s.name.clone(),
+            score: 0,
+            indices: Vec::new(),
+        });
+        if let Some(children) = s.children {
+            let parent = Some(s.name.replace('\n', "↵"));
+            for child in children {
+                Self::format_document_symbol(items, parent.clone(), child);
+            }
+        }
+    }
+
     fn get_workspace_symbols(&self) {
         let input = self.input.get_untracked().input;
 
@@ -1506,6 +1532,8 @@ impl PaletteData {
         // NOTE: We collect into a Vec to sort as we are hitting a worst-case behavior in
         // `im::Vector` that can lead to a stack overflow!
         let mut filtered_items = Vec::new();
+        let mut indices = Vec::new();
+        let mut filter_text_buf = Vec::new();
         for i in &items {
             // If the run id has ever changed, then we'll just bail out of this filtering to avoid
             // wasting effort. This would happen, for example, on the user continuing to type.
@@ -1513,14 +1541,14 @@ impl PaletteData {
                 return None;
             }
 
-            let mut indices = Vec::new();
-            let mut filter_text_buf = Vec::new();
+            indices.clear();
+            filter_text_buf.clear();
             let filter_text = Utf32Str::new(&i.filter_text, &mut filter_text_buf);
             if let Some(score) = pattern.indices(filter_text, matcher, &mut indices)
             {
                 let mut item = i.clone();
                 item.score = score;
-                item.indices = indices.into_iter().map(|i| i as usize).collect();
+                item.indices = indices.iter().map(|i| *i as usize).collect();
                 filtered_items.push(item);
             }
         }
