@@ -7,7 +7,7 @@ use floem::{
     peniko::kurbo::{Point, Rect, Size},
     reactive::{
         create_effect, create_memo, create_rw_signal, Memo, ReadSignal, RwSignal,
-        Scope,
+        Scope, SignalGet, SignalUpdate, SignalWith,
     },
     style::CursorStyle,
     text::{Attrs, AttrsList, FamilyOwned, TextLayout},
