@@ -135,8 +135,9 @@ impl DapClient {
                                 DapEvent::Initialized(None),
                             ));
                             plugin_rpc.core_rpc.log(
-                                tracing::Level::ERROR,
+                                lapce_rpc::core::LogLevel::Error,
                                 format!("dap server {program} stopped!"),
+                                None,
                             );
 
                             dap_rpc.disconnected();
@@ -243,7 +244,7 @@ impl DapClient {
 
                 let active_frame = current_thread
                     .and_then(|thread_id| stack_frames.get(&thread_id))
-                    .and_then(|stack_frames| stack_frames.get(0));
+                    .and_then(|stack_frames| stack_frames.first());
 
                 let mut vars = Vec::new();
                 if let Some(frame) = active_frame {
