@@ -16,7 +16,7 @@ use floem_editor_core::buffer::rope_text::{RopeText, RopeTextRef};
 use jsonrpc_lite::{Id, JsonRpc, Params};
 use lapce_core::{encoding::offset_utf16_to_utf8, rope_text_pos::RopeTextPosition};
 use lapce_rpc::{
-    core::CoreRpcHandler,
+    core::{CoreRpcHandler, ServerStatusParams},
     plugin::{PluginId, VoltID},
     style::{LineStyle, Style},
     RpcError,
@@ -29,7 +29,8 @@ use lsp_types::{
         ShowMessage,
     },
     request::{
-        CodeActionRequest, CodeActionResolveRequest, Completion,
+        CallHierarchyIncomingCalls, CallHierarchyPrepare, CodeActionRequest,
+        CodeActionResolveRequest, CodeLensRequest, Completion,
         DocumentSymbolRequest, Formatting, GotoDefinition, GotoTypeDefinition,
         HoverRequest, Initialize, InlayHintRequest, InlineCompletionRequest,
         PrepareRenameRequest, References, RegisterCapability, Rename,
@@ -38,7 +39,7 @@ use lsp_types::{
     },
     CodeActionProviderCapability, DidChangeTextDocumentParams,
     DidSaveTextDocumentParams, DocumentSelector, HoverProviderCapability,
-    InitializeResult, LogMessageParams, OneOf, ProgressParams,
+    InitializeResult, LogMessageParams, MessageType, OneOf, ProgressParams,
     PublishDiagnosticsParams, Range, Registration, RegistrationParams,
     SemanticTokens, SemanticTokensLegend, SemanticTokensServerCapabilities,
     ServerCapabilities, ShowMessageParams, TextDocumentContentChangeEvent,
@@ -134,6 +135,7 @@ pub enum PluginServerRpc {
     HostNotification {
         method: String,
         params: Params,
+        from: String,
     },
     DidSaveTextDocument {
         language_id: String,
@@ -209,7 +211,12 @@ pub trait PluginServerHandler {
         path: Option<&Path>,
     ) -> bool;
     fn method_registered(&mut self, method: &str) -> bool;
-    fn handle_host_notification(&mut self, method: String, params: Params);
+    fn handle_host_notification(
+        &mut self,
+        method: String,
+        params: Params,
+        from: String,
+    );
     fn handle_host_request(
         &mut self,
         id: Id,
@@ -470,8 +477,12 @@ impl PluginServerRpcHandler {
                 } => {
                     handler.handle_host_request(id, method, params, resp);
                 }
-                PluginServerRpc::HostNotification { method, params } => {
-                    handler.handle_host_notification(method, params);
+                PluginServerRpc::HostNotification {
+                    method,
+                    params,
+                    from,
+                } => {
+                    handler.handle_host_notification(method, params, from);
                 }
                 PluginServerRpc::DidSaveTextDocument {
                     language_id,
@@ -520,6 +531,7 @@ impl PluginServerRpcHandler {
 pub fn handle_plugin_server_message(
     server_rpc: &PluginServerRpcHandler,
     message: &str,
+    from: &str,
 ) -> Option<JsonRpc> {
     match JsonRpc::parse(message) {
         Ok(value @ JsonRpc::Request(_)) => {
@@ -550,6 +562,7 @@ pub fn handle_plugin_server_message(
             let rpc = PluginServerRpc::HostNotification {
                 method: value.get_method().unwrap().to_string(),
                 params: value.get_params().unwrap(),
+                from: from.to_string(),
             };
             server_rpc.handle_rpc(rpc);
             None
@@ -780,6 +793,15 @@ impl PluginHostHandler {
             CodeActionResolveRequest::METHOD => {
                 self.server_capabilities.code_action_provider.is_some()
             }
+            CodeLensRequest::METHOD => {
+                self.server_capabilities.code_lens_provider.is_some()
+            }
+            CallHierarchyPrepare::METHOD => {
+                self.server_capabilities.call_hierarchy_provider.is_some()
+            }
+            CallHierarchyIncomingCalls::METHOD => {
+                self.server_capabilities.call_hierarchy_provider.is_some()
+            }
             _ => false,
         }
     }
@@ -1009,6 +1031,7 @@ impl PluginHostHandler {
         &mut self,
         method: String,
         params: Params,
+        from: String,
     ) -> Result<()> {
         match method.as_str() {
             // TODO: remove this after the next release and once we convert all the existing plugins to use the request.
@@ -1072,6 +1095,22 @@ impl PluginHostHandler {
                     ),
                 );
             }
+            "experimental/serverStatus" => {
+                let param: ServerStatusParams =
+                    serde_json::from_value(serde_json::to_value(params)?)?;
+                if !param.is_ok() {
+                    if let Some(msg) = &param.message {
+                        self.core_rpc.show_message(
+                            from,
+                            ShowMessageParams {
+                                typ: MessageType::ERROR,
+                                message: msg.clone(),
+                            },
+                        );
+                    }
+                }
+                self.catalog_rpc.core_rpc.server_status(param);
+            }
             _ => {
                 self.core_rpc.log(
                     lapce_rpc::core::LogLevel::Warn,
